@@ -1211,7 +1211,7 @@ class Chemical:
         self._Tt = Tt or triple_point_temperature(CAS)
 
         # Energy
-        self._Hfus = Hfus if Hf is not None else heat_of_fusion(CAS)
+        self._Hfus = Hfus if Hfus is not None else heat_of_fusion(CAS)
 
         # Chemistry
         self._Hf = Hf if Hf is not None else heat_of_formation(CAS)
