@@ -227,6 +227,8 @@ chemical_units_of_measure = {'MW': AbsoluteUnitsOfMeasure('g/mol'),
                              'Hc': AbsoluteUnitsOfMeasure('J/mol'), 
                              'Hfus': AbsoluteUnitsOfMeasure('J/mol'), 
                              'Hsub': AbsoluteUnitsOfMeasure('J/mol'),
+                             'HHV': AbsoluteUnitsOfMeasure('J/mol'),
+                             'LHV': AbsoluteUnitsOfMeasure('J/mol'),
                              'S': AbsoluteUnitsOfMeasure('J/mol'), 
                              'G': AbsoluteUnitsOfMeasure('J/mol'), 
                              'U': AbsoluteUnitsOfMeasure('J/mol'), 
