@@ -6,12 +6,12 @@ Created on Wed Mar 20 18:40:05 2019
 """
 from flexsolve import wegstein, IQ_interpolation, aitken, SolverError
 from ..utils.decorator_utils import thermo_user
-from .binary_phase_fraction import phase_fraction
+from . import binary_phase_fraction as binary
 from .dew_point import DewPointCache
 from .bubble_point import BubblePointCache
 from .fugacity_coefficients import IdealFugacityCoefficients
 from .._thermal_condition import ThermalCondition
-from ..functional import normalize
+from .. import functional as fn
 from ..utils import Cache
 import numpy as np
 
@@ -636,7 +636,7 @@ class VLE:
         x = x/x.sum()
         x[x < 1e-16] = 1e-16
         self._Ks = Psat_over_P_phi * self._gamma(x, self._T) * self._pcf(x, self._T)
-        self._V = V = phase_fraction(self._z, self._Ks, self._V)
+        self._V = V = binary.phase_fraction(self._z, self._Ks, self._V)
         return self._z/(1. + V * (self._Ks - 1.))
     
     def _y_iter(self, y, Psats_over_P, T, P):
@@ -652,7 +652,7 @@ class VLE:
                             args=(Psat_over_P_phi,))
         self._x = x
         v = self._F_mol_vle * self._V * x * self._Ks     
-        return normalize(v)
+        return fn.normalize(v)
     
     def _solve_v(self, T, P):
         """Solve for vapor mol"""
@@ -660,9 +660,9 @@ class VLE:
                                  self._bubble_point.Psats]) / P
         self._T = T
         v = self._v
-        y = normalize(v)
+        y = fn.normalize(v)
         l = self._mol - v
-        self._x = normalize(l)
+        self._x = fn.normalize(l)
         if isinstance(self._phi, IdealFugacityCoefficients):
             self._y = self._y_iter(y, Psats_over_P, T, P)
         else:
